.. nodoctest

Combinat Grid View Adapters
===========================

.. automodule:: sage_widget_adapters.combinat.partition_grid_view_adapter
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: sage_widget_adapters.combinat.skew_partition_grid_view_adapter
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: sage_widget_adapters.combinat.tableau_grid_view_adapter
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: sage_widget_adapters.combinat.skew_tableau_grid_view_adapter
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: sage_widget_adapters.combinat.parallelogram_polyomino_grid_view_adapter
   :members:
   :undoc-members:
   :show-inheritance:
